@@ -5,7 +5,7 @@ package Text::PerlPP;
 
 # Semantic versioning, packed per Perl rules.  Must always be at least one
 # digit left of the decimal, and six digits right of the decimal.
-our $VERSION = '0.600_000';
+our $VERSION = '0.500001';
 
 use 5.010001;
 use strict;
@@ -13,6 +13,7 @@ use warnings;
 
 use Getopt::Long 2.5 qw(GetOptionsFromArray);
 use Pod::Usage;
+use Data::Dumper;
 
 # === Constants ===========================================================
 
@@ -130,6 +131,9 @@ sub StartOB {
 	if ( scalar @{$self->{OutputBuffers}} == 0 ) {
 		$| = 1;					# flush contents of STDOUT
 		open( $self->{RootSTDOUT}, ">&STDOUT" ) or die $!;		# dup filehandle
+		#$self->{RootSTDOUT} = $fh;
+		#undef $fh;
+		#say STDERR "stdout in startob ", Dumper($self->{RootSTDOUT});
 	}
 	unshift( @{$self->{OutputBuffers}}, [ $mode, "", $lineno ] );
 	close( STDOUT );			# must be closed before redirecting it to a variable
@@ -667,24 +671,17 @@ sub Include {	# As ProcessFile(), but for use within :macro
 	$self->StartOB();		# re-open a plain-text OB
 } #Include
 
-sub FinalizeResult {
-	my $self = shift;
-	my $contents_ref = shift;					# reference
-
-	for my $proc ( @{$self->{Postprocessors}} ) {
-		&$proc( $contents_ref );
-	}
-	return $contents_ref;
-} #FinalizeResult()
-
 sub OutputResult {
 	my $self = shift;
 	my $contents_ref = shift;					# reference
 	my $fname = shift;	# "" or other false value => STDOUT
-
-	$self->FinalizeResult( $contents_ref );
-
+	my $proc;
 	my $out_fh;
+
+	for $proc ( @{$self->{Postprocessors}} ) {
+		&$proc( $contents_ref );
+	}
+
 	if ( $fname ) {
 		open( $out_fh, ">", $fname ) or die $!;
 	} else {
@@ -780,7 +777,12 @@ sub _parse_command_line {
 	# Map the option names from GetOptions back to the internal names we use,
 	# e.g., $hrOptsOut->{EVAL} from $hrOptsOut->{e}.
 	my %revmap = map { $CMDLINE_OPTS{$_}->[0] => $_ } keys %CMDLINE_OPTS;
+	#say "revmap ", Dumper(\%revmap);
+	#say "hrOptsOut ", Dumper($hrOptsOut);
 	for my $optname (keys %$hrOptsOut) {
+		#say "\nOptname $optname";
+		#say "Value $hrOptsOut->{$optname}";
+		#say "Revmap $revmap{$optname}";
 		$hrOptsOut->{ $revmap{$optname} } = $hrOptsOut->{ $optname };
 	}
 
@@ -806,9 +808,8 @@ sub Main {
 	}
 
 	if($self->{Opts}->{PRINT_VERSION}) {	# print version, raw and dotted
-		$Text::PerlPP::VERSION =~ m<^([^\.]+)\.(\d{3})(_?)(\d{3})>;
-		printf "PerlPP version %d.%d.%d ($VERSION)%s\n", $1, $2, $4,
-			($3 ? ' (dev)' : '');
+		$Text::PerlPP::VERSION =~ m<^([^\.]+)\.(\d{3})(\d{3})>;
+		printf "PerlPP version %d.%d.%d ($VERSION)\n", $1, $2, $3;
 		if($self->{Opts}->{PRINT_VERSION} > 1) {
 			print "Script: $0\nText::PerlPP: $INC{'Text/PerlPP.pm'}\n";
 		}
